"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rotating_file_stream_1 = require("rotating-file-stream");
var path_1 = require("path");
var moment = require("moment");
var qs_1 = require("qs");
var debug_helper_1 = require("./util/debug_helper");
var logError = debug_helper_1.default(__filename).logError;
var baseAxiosConfig = {
    timeout: 10000,
    headers: {
        'User-Agent': 'ts-crypto-cli',
        'content-type': 'application/x-www-form-urlencoded',
    }
};
exports.baseAxiosConfig = baseAxiosConfig;
var _a = process.env.TS_CRYPTO_CLI_LOGS_PATH, TS_CRYPTO_CLI_LOGS_PATH = _a === void 0 ? path_1.resolve(__dirname, '..', '.logs') : _a;
var dirPath = path_1.resolve(TS_CRYPTO_CLI_LOGS_PATH);
// Rotating filenames
var calculateFileName = function (date, index) {
    var fileName = "ts-crypto-cli_" + moment().utc().format('YYYY_MMM');
    if (!date)
        return fileName + ".csv";
    return fileName + "_" + index + ".csv";
};
var stream = rotating_file_stream_1.createStream(calculateFileName, {
    size: "100M",
    interval: "1M",
    path: dirPath,
    immutable: true,
});
var baseAxiosRequestInterceptor = function (config) {
    if (['PUT', 'POST', 'PATCH'].includes(config.method.toUpperCase())) {
        delete config.params;
        config.data = qs_1.stringify(config.data);
    }
    else {
        delete config.data;
    }
    var method = config.method, baseURL = config.baseURL, url = config.url, _a = config.params, params = _a === void 0 ? '-' : _a, _b = config.data, data = _b === void 0 ? '-' : _b;
    stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + data + "; -; -; -");
    return config;
};
exports.baseAxiosRequestInterceptor = baseAxiosRequestInterceptor;
var baseAxiosResponseInterceptor = function (response) {
    var _a = response.config, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, status = response.status, _c = response.statusText, statusText = _c === void 0 ? '-' : _c, _d = response.data, data = _d === void 0 ? '-' : _d;
    stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + typeof data + "; " + status + "; " + statusText + "; -");
    return response;
};
exports.baseAxiosResponseInterceptor = baseAxiosResponseInterceptor;
var baseAxiosRequestErrorInterceptor = function (axiosRequestError) {
    var _a = axiosRequestError.config, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, _c = _a.data, data = _c === void 0 ? '-' : _c, _d = axiosRequestError.code, code = _d === void 0 ? '-' : _d, _e = axiosRequestError.response, status = _e.status, _f = _e.statusText, statusText = _f === void 0 ? '-' : _f;
    stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + JSON.stringify(data) + "; " + status + "; " + statusText + "; " + code);
    logError({ axiosRequestError: axiosRequestError });
    throw axiosRequestError;
};
exports.baseAxiosRequestErrorInterceptor = baseAxiosRequestErrorInterceptor;
var baseAxiosResponseErrorInterceptor = function (axiosResponseError) {
    var _a = axiosResponseError.config, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, _c = _a.data, data = _c === void 0 ? '-' : _c, _d = axiosResponseError.code, code = _d === void 0 ? '-' : _d, _e = axiosResponseError.response, status = _e.status, _f = _e.statusText, statusText = _f === void 0 ? '-' : _f;
    stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + typeof data + "; " + status + "; " + statusText + "; " + code);
    logError({ axiosResponseError: axiosResponseError });
    throw axiosResponseError;
};
exports.baseAxiosResponseErrorInterceptor = baseAxiosResponseErrorInterceptor;
